{#-
# ozi/templates/tests/meson.build.j2
# SPDX-License-Identifier: Unlicense
-#}
[wrap-git]
url = https://github.com/OZI-Project/ozi.git
revision = release/{{ ozi.version }}
depth = 1

[provide]
dependency_names = ozi-{{ spec.version }}
